class DataTransformer:
    def __init__(self, data):
        self.data = data

    def transform_data(self):
        # Logika transformacji danych z API
        transformed_data = ...
        return transformed_data
