from setuptools import setup, find_packages

setup(
    name='biblioteka',
    version='1.0',
    author='Michal',
    url='https://git.e-science.pl/micpuc157_dpp_2023.group/python_pip',
    packages=find_packages(),
)
